searchData={"items":[{"type":"task","title":"mix validate_tasklist","doc":"Validates the format and structure of a TaskList.md file.\n\nValidates that task lists follow the required format:\n- Task IDs must follow a consistent pattern: 2-4 uppercase letters followed by 3-4 digits\n- Subtasks must use the same prefix as their parent task\n- Required sections are present for each task\n- Tasks marked as \"In Progress\" have at least one subtask\n- Completed subtasks have a valid review rating","ref":"Mix.Tasks.ValidateTasklist.html"},{"type":"task","title":"Usage - mix validate_tasklist","doc":"mix validate_tasklist [OPTIONS]","ref":"Mix.Tasks.ValidateTasklist.html#module-usage"},{"type":"task","title":"Options - mix validate_tasklist","doc":"--path  Specify a non-default path to the TaskList.md file","ref":"Mix.Tasks.ValidateTasklist.html#module-options"},{"type":"task","title":"Example - mix validate_tasklist","doc":"mix validate_tasklist\n    mix validate_tasklist --path ./custom/path/TaskList.md","ref":"Mix.Tasks.ValidateTasklist.html#module-example"},{"type":"function","title":"Mix.Tasks.ValidateTasklist.run/1","doc":"Callback implementation for  Mix.Task.run/1 .","ref":"Mix.Tasks.ValidateTasklist.html#run/1"},{"type":"module","title":"TaskValidator","doc":"Validates TaskList.md format compliance according to project guidelines.\n\nChecks for:\n- ID format compliance (like SSH0001, SCP0001, ERR001, etc.)\n- Unique task IDs\n- Required sections and fields in tasks\n- Proper subtask structure\n- Valid status values\n- Review rating format","ref":"TaskValidator.html"},{"type":"function","title":"TaskValidator.extract_tasks/1","doc":"Extracts tasks from the TaskList.md content.","ref":"TaskValidator.html#extract_tasks/1"},{"type":"function","title":"TaskValidator.validate_file/1","doc":"Validates a TaskList.md file against the specified format requirements.\n\nReturns `:ok` if validation passes, or `{:error, reason}` if it fails.","ref":"TaskValidator.html#validate_file/1"},{"type":"extras","title":"TaskValidator","doc":"# TaskValidator\n\nA library for validating Markdown task lists against a structured format specification.","ref":"readme.html"},{"type":"extras","title":"Installation - TaskValidator","doc":"Add `task_validator` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:task_validator, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - TaskValidator","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Command Line - TaskValidator","doc":"```bash\n# Validate the default TaskList.md file\nmix validate_tasklist\n\n# Validate a custom file path\nmix validate_tasklist --path ./path/to/custom/TaskList.md\n```","ref":"readme.html#command-line"},{"type":"extras","title":"Programmatic - TaskValidator","doc":"```elixir\ncase TaskValidator.validate_file(\"path/to/tasklist.md\") do\n  {:ok, message} ->\n    IO.puts(\"Success: #{message}\")\n  {:error, reason} ->\n    IO.puts(\"Error: #{reason}\")\nend\n```","ref":"readme.html#programmatic"},{"type":"extras","title":"Format Specification - TaskValidator","doc":"The TaskValidator enforces a specific format for task lists:\n\n- Task IDs must follow a consistent pattern: 2-4 uppercase letters followed by 3-4 digits (e.g., SSH0001, SCP0001, ERR001, REF0002)\n- Subtasks must use the same prefix as their parent task (e.g., SSH0001-1 for a subtask of SSH0001)\n- Each task must have required sections (Description, Status, Priority, etc.)\n- Tasks marked as \"In Progress\" must have subtasks\n- Review ratings must follow the specified format (1-5 scale)","ref":"readme.html#format-specification"},{"type":"extras","title":"Multi-Project Support - TaskValidator","doc":"The task validator supports multiple project prefixes in the same task list. Each prefix typically represents a different component or subproject:\n\n```markdown","ref":"readme.html#multi-project-support"},{"type":"extras","title":"Current Tasks - TaskValidator","doc":"| ID      | Description          | Status      | Priority |\n| ------- | -------------------- | ----------- | -------- |\n| SSH0001 | SSH authentication   | In Progress | High     |\n| SCP0001 | File transfer module | Planned     | Medium   |\n| ERR001  | Error handling       | In Progress | High     |\n```\n\nThe validator ensures consistency within each task hierarchy, so a task with ID \"SSH0001\" must have subtasks with IDs like \"SSH0001-1\", \"SSH0001-2\", etc.","ref":"readme.html#current-tasks"},{"type":"extras","title":"Example Files - TaskValidator","doc":"The repository includes several example files in the `test/fixtures` directory:\n\n- `sample_tasklist.md` - A basic valid task list\n- `multi_prefix_tasklist.md` - A valid task list with multiple project prefixes\n- `prefix_mismatch.md` - Demonstrates prefix mismatch validation (subtask has different prefix than parent)\n- `invalid_rating.md` - Shows validation of review rating format\n- `invalid_mix_prefixes.md` - Contains various validation errors\n\nYou can test validation against these examples:\n\n```bash\nmix validate_tasklist --path test/fixtures/multi_prefix_tasklist.md  # Should pass\nmix validate_tasklist --path test/fixtures/prefix_mismatch.md        # Should fail\n```","ref":"readme.html#example-files"},{"type":"extras","title":"License - TaskValidator","doc":"MIT License\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.0"}}